@@ -87,12 +87,13 @@ sd_ui <- function() {
       shinyjs::useShinyjs(),
       load_resource(
         "auto_scroll.js",
+        "cookies.js",
         "countdown.js",
         "enter_key.js",
         "keep_alive.js",
         "surveydown.css"
       ),
-      if (theme == "default") {
+      if (any(theme == "default")) {
         load_resource("default_theme.css")
       },
       shiny::tags$script("var surveydownConfig = {};"),
@@ -239,13 +240,21 @@ sd_question <- function(
 
     output <- NULL
 
+    # Load translations for selected label and date language option
+    translations <- get_translations()
+    language <- translations$language
+    translations <- translations$translations
+
     # Check if question if answered
     js_interaction <- sprintf("Shiny.setInputValue('%s_interacted', true, {priority: 'event'});", id)
 
     # Create label with hidden asterisk
     label <- markdown_to_html(label)
 
-    if (type ==  "select") {
+    if (type == "select") {
+        label_select <- translations[['choose_option']]
+
+        # Add blank option for visible selected option
         option <- c("", option)
         names(option)[1] <- label_select
 
@@ -256,7 +265,6 @@ sd_question <- function(
             multiple = FALSE,
             selected = FALSE
         )
-
     } else if (type == "mc") {
 
         output <- shiny::radioButtons(
@@ -370,7 +378,7 @@ sd_question <- function(
             format             = "mm/dd/yyyy",
             startview          = "month",
             weekstart          = 0,
-            language           = "en",
+            language           = language,
             autoclose          = TRUE,
             datesdisabled      = NULL,
             daysofweekdisabled = NULL
@@ -390,7 +398,7 @@ sd_question <- function(
             format    = "mm/dd/yyyy",
             startview = "month",
             weekstart = 0,
-            language  = "en",
+            language  = language,
             separator = "-",
             autoclose = TRUE
         )
@@ -481,7 +489,8 @@ make_question_container <- function(id, object, width) {
 #' The button can be activated by clicking or by pressing the Enter key when visible.
 #'
 #' @param next_page Character string. The ID of the next page to navigate to. This parameter is required.
-#' @param label Character string. The label of the 'Next' button. Defaults to "Next".
+#' @param label Character string. The label of the 'Next' button. Defaults to
+#'   `NULL`, in which case the word `"Next"` will be used.
 #'
 #' @details The function generates a 'shiny' action button that, when clicked
 #' or when the Enter key is pressed, sets the input value to the specified next
@@ -518,21 +527,29 @@ make_question_container <- function(id, object, width) {
 #' }
 #'
 #' @export
-sd_next <- function(next_page = NULL, label = "Next") {
-  button_id <- "page_id_next"  # Placeholder ID
-  shiny::tagList(
-    shiny::div(
-      `data-next-page` = if (!is.null(next_page)) next_page else "",
-      style = "margin-top: 0.5rem; margin-bottom: 0.5rem;",
-      shiny::actionButton(
-        inputId = button_id,
-        label = label,
-        class = "sd-enter-button",
-        style = "display: block; margin: auto;",
-        onclick = "Shiny.setInputValue('next_page', this.parentElement.getAttribute('data-next-page'));"
-      )
+sd_next <- function(next_page = NULL, label = NULL) {
+    # Get translations
+    translations <- get_translations()$translations
+
+    # If no label provided, use default
+    if (is.null(label)) {
+        label <- translations[['next']]
+    }
+
+    button_id <- "page_id_next"  # Placeholder ID
+    shiny::tagList(
+        shiny::div(
+            `data-next-page` = if (!is.null(next_page)) next_page else "",
+            style = "margin-top: 0.5rem; margin-bottom: 0.5rem;",
+            shiny::actionButton(
+                inputId = button_id,
+                label = label,
+                class = "sd-enter-button",
+                style = "display: block; margin: auto;",
+                onclick = "Shiny.setInputValue('next_page', this.parentElement.getAttribute('data-next-page'));"
+            )
+        )
     )
-  )
 }
 
 # Generate Next Button ID
@@ -546,7 +563,8 @@ make_next_button_id <- function(page_id) {
 #' for the survey. Depending on the server-side configuration, this may show a rating question
 #' or a simple confirmation dialog before attempting to close the current browser tab or window.
 #'
-#' @param label Character string. The label of the 'Close' button. Defaults to "Exit Survey".
+#' @param label Character string. The label of the 'Close' button. Defaults to
+#'    `NULL`, in which case the word `"Exit Survey"` will be used.
 #'
 #' @return A 'shiny' tagList containing the 'Close' button UI element and
 #' associated JavaScript for the exit process.
@@ -595,7 +613,15 @@ make_next_button_id <- function(page_id) {
 #' @seealso \code{\link{sd_server}}
 #'
 #' @export
-sd_close <- function(label = "Exit Survey") {
+sd_close <- function(label = NULL) {
+  # Get translations
+  translations <- get_translations()$translations
+
+  # If no label provided, use default
+  if (is.null(label)) {
+      label <- translations[['exit']]
+  }
+
   button_id <- "close-survey-button"
   shiny::tagList(
     shiny::div(
@@ -630,8 +656,8 @@ sd_close <- function(label = "Exit Survey") {
 #' @param url A character string specifying the URL to redirect to.
 #' @param button A logical value indicating whether to create a button (`TRUE`)
 #'   or a text element (`FALSE`) for the redirect. Default is `TRUE`.
-#' @param label A character string for the button or text label. Default is
-#'   "Click here".
+#' @param label A character string for the button or text label. Defaults to
+#'   `NULL`, in which case the words `"Click here"` will be used.
 #' @param delay An optional numeric value specifying the delay in seconds before
 #'   automatic redirection. If `NULL` (default), no automatic redirection
 #'   occurs.
@@ -698,6 +724,14 @@ sd_redirect <- function(
     delay  = NULL,
     newtab = FALSE
 ) {
+    # Get translations
+    translations <- get_translations()$translations
+
+    # If no label provided, use default
+    if (is.null(label)) {
+        label <- translations[['click']]
+    }
+
     if (!is.null(shiny::getDefaultReactiveDomain())) {
         # In a reactive context, directly add to output with renderUI
         shiny::isolate({
@@ -737,6 +771,13 @@ create_redirect_element <- function(id, url, button, label, delay, newtab = FALS
         element <- shiny::span(label)
     }
 
+    # Get translations
+    translations <- get_translations()$translations
+    text_redirect <- translations[["redirect"]]
+    text_seconds <- translations[["seconds"]]
+    text_newtab <- translations[["new_tab"]]
+    text_error <- translations[["redirect_error"]]
+
     # Add automatic redirection if delay is specified
     if (!is.null(delay) && is.numeric(delay) && delay > 0) {
         countdown_id <- paste0("countdown_", id)
@@ -749,10 +790,14 @@ create_redirect_element <- function(id, url, button, label, delay, newtab = FALS
                     element,
                     shiny::p(
                         style = "margin: 0.5rem 0 0 0;",
-                        "Redirecting in ",
+                        text_redirect, " ",
                         shiny::tags$strong(id = countdown_id, delay),
-                        " seconds.",
-                        if (newtab) " (Opens in a new tab)" else NULL
+                        " ", text_seconds, ".",
+                        if (newtab) {
+                          glue::glue(" ({text_newtab})")
+                        } else {
+                          NULL
+                        }
                     )
                 )
             ),
@@ -771,7 +816,7 @@ create_redirect_element <- function(id, url, button, label, delay, newtab = FALS
             shiny::div(
                 class = "sd-container",
                 element,
-                shiny::p(style = "margin: 0.5rem 0 0 0;", "Error: This text won't trigger any redirection...")
+                shiny::p(style = "margin: 0.5rem 0 0 0;", text_error)
             )
         )
     } else {
