@@ -30,14 +30,9 @@ list_name_md_to_html <- function(list) {
 .onAttach <- function(libname, pkgname) {
 
     # Add special folders to resource path
-    folders <- c('images', 'css', 'js', 'www')
+    folders <- c('_survey', 'images', 'css', 'js', 'www')
     for (folder in folders) { include_folder(folder) }
 
-    # Add survey_files folder to resource path
-    # (if survey.qmd exists and it's not self contained)
-    folder <- get_survey_file_folder()
-    if (!is.null(folder)) { include_folder(folder, create = TRUE) }
-
     # Print package data
     desc  <- utils::packageDescription(pkgname, libname)
     packageStartupMessage(
@@ -49,24 +44,27 @@ list_name_md_to_html <- function(list) {
     )
 }
 
-get_survey_file_folder <- function() {
-    if (!survey_file_exists()) { return(NULL) }
-    if (!is_self_contained("survey.qmd")) {
-        return("survey_files")
-    }
-    return(NULL)
-}
-
 survey_file_exists <- function() {
     files <- basename(list.files(full.names = TRUE))
     if ("survey.qmd" %in% files) { return(TRUE) }
     return(FALSE)
 }
 
-is_self_contained <- function(x) {
-    result <- quarto::quarto_inspect(x)$formats$html$pandoc$`self-contained`
-    if (is.null(result)) { return(FALSE) }
-    return(result)
+is_self_contained <- function() {
+    metadata <- quarto::quarto_inspect("survey.qmd")
+    embedded <- metadata$formats$html$pandoc$`embed-resources`
+    if (!is.null(embedded)) {
+        if (embedded) {
+            return(TRUE)
+        }
+    }
+    self <- metadata$formats$html$pandoc$`self-contained`
+    if (!is.null(self)) {
+        if (self) {
+            return(TRUE)
+        }
+    }
+    return(FALSE)
 }
 
 include_folder <- function(folder, create = FALSE) {
@@ -597,3 +595,82 @@ get_latest_version <- function(url, pattern) {
         return(NULL)
     })
 }
+
+#' Create a translations template file
+#'
+#' This function creates a template translations.yml file in the project root directory
+#' that users can customize to modify system messages.
+#'
+#' @param language Character string specifying the language to use. See
+#'   https://shiny.posit.co/r/reference/shiny/1.7.0/dateinput for supported
+#'   languages. Also, if `"en"`, `"de"`, `"es"`, `"fr"`, or `"it"` is chosen,
+#'   default messages in those langauges will be used, otherwise the default
+#'   English messages will be used. Defaults to `"en"`.
+#' @param path Character string specifying the directory where the translations.yml
+#'   file should be created. Defaults to the current working directory. The
+#'   file should be placed in the root project folder of your surveydown survey.
+#' @return Invisible `NULL`.
+#' @export
+#'
+#' @examples
+#' if (interactive()) {
+#'   # Create English template
+#'   sd_create_translations()
+#'
+#'   # Create German template
+#'   sd_create_translations(language = "de")
+#'
+#'   # Create Japanese template
+#'   # Will use English messages but Japanese date picker - user can modify
+#'   # the messages as desired
+#'   sd_create_translations(language = "ja")
+#' }
+sd_create_translations <- function(language = "en", path = getwd()) {
+  # Define valid languages
+  valid_languages <- get_valid_languages()
+
+  # Check if language is valid
+  if (is.null(language) || !(language %in% valid_languages)) {
+    stop(
+      "Invalid language selected. Check https://shiny.posit.co/r/reference/shiny/1.7.0/dateinput for supported languages."
+    )
+  }
+
+  # Get default translations
+  translations <- get_translations_default()
+
+  # If language has default messages, use them; otherwise use English
+  template <- list()
+  if (language %in% names(translations)) {
+    template[[language]] <- translations[[language]]
+  } else {
+    template[[language]] <- translations[["en"]]
+    message(
+      "No default messages available for '", language,
+      "'. Using English messages with ", language, " date picker."
+    )
+  }
+
+  # Create the file path
+  file_path <- file.path(path, "translations.yml")
+
+  # Check if file already exists
+  if (file.exists(file_path)) {
+    stop("translations.yml already exists in the specified path")
+  }
+
+  # Define template header
+  header <- paste(
+    "# Surveydown translations template",
+    "# Edit the values below to customize system messages",
+    "# Keep the structure and keys unchanged",
+    "",
+    sep = "\n"
+  )
+
+  # Write question to YAML (with comment in first lines)
+  yaml_content <- paste0(header, yaml::as.yaml(template))
+  writeLines(yaml_content, con = file_path)
+  message("Created translations template at: ", file_path)
+  invisible(NULL)
+}
